import type { NativeModule } from "expo-modules-core/types";
import { ConfigurationOptions } from "./ReactNativeMobileWhepClient.types";
declare const brand: unique symbol;
export type Brand<T, TBrand extends string> = T & {
    [brand]: TBrand;
};
/** A unique ID of the camera.  */
export type CameraId = Brand<string, "CameraId">;
/** Describes whether the camera is front-facing or back-facing. */
export type CameraFacingDirection = "front" | "back" | "unspecified";
/** Contains information about the camera available on the device. */
export type Camera = {
    /** A unique ID of the camera.  */
    id: CameraId;
    /** A string describing camera name. */
    name: string;
    /** Information about the camera being a front one or back one. */
    facingDirection: CameraFacingDirection;
};
type RNMobileWhepClientModule = {
    createWhepClient: (serverUrl: string, configurationOptions?: ConfigurationOptions) => void;
    connectWhep: () => Promise<void>;
    disconnectWhep: () => void;
    pauseWhep: () => void;
    unpauseWhep: () => void;
    createWhipClient: (serverUrl: string, configurationOptions?: ConfigurationOptions, videoDevice?: CameraId) => void;
    connectWhip: () => Promise<void>;
    disconnectWhip: () => void;
    cameras: readonly Camera[];
};
export declare const ReceivableEvents: {
    readonly reconnectionStatusChanged: "reconnectionStatusChanged";
};
export type ReceivableEventPayloads = {
    [ReceivableEvents.reconnectionStatusChanged]: {
        status: "reconnectionStarted" | "reconnected" | "reconnectionRetriesLimitReached";
    };
};
declare const nativeModule: RNMobileWhepClientModule & NativeModule<Record<keyof typeof ReceivableEvents, (payload: any) => void>>;
/** Creates a WHEP client based on the provided server URL and optional additional `configurationOptions`.
 *  It is a first step before connecting to the server.
 */
export declare function createWhepClient(
/** URL of the WHEP server from which the stream should be received. */
serverUrl: string, 
/** Additional configuration options. */
configurationOptions?: ConfigurationOptions): void;
/** Connects to the WHEP server defined while creating WHEP client.
 * Allows user to receive video and audio stream.
 */
export declare function connectWhepClient(): Promise<void>;
/** Disconnects from the WHEP server defined while creating WHEP client.
 * Frees the resources.
 */
export declare function disconnectWhepClient(): void;
/** Pauses the WHEP stream, making the view black and disabling the sound. */
export declare function pauseWhepClient(): void;
/** Restarts the WHEP stream. Makes the view reappear along with sound. */
export declare function unpauseWhepClient(): void;
/** Creates a WHIP client based on the provided server URL and optional additional `configurationOptions`.
 * Allows user to choose a streaming device from all available cameras.
 *  It is a first step before connecting to the server.
 */
export declare function createWhipClient(serverUrl: string, configurationOptions?: ConfigurationOptions, videoDevice?: CameraId): void;
/** Connects to the WHIP server defined while creating WHIP client.
 * Allows user to stream video and audio.
 */
export declare function connectWhipClient(): Promise<void>;
/** Disconnects from the WHIP server defined while creating WHIP client.
 * Frees the resources.
 */
export declare function disconnectWhipClient(): void;
/** Gives access to the cameras available on the device.*/
export declare const cameras: readonly Camera[];
export default nativeModule;
//# sourceMappingURL=ReactNativeMobileWhepClientModule.d.ts.map