import { requireNativeModule } from "expo-modules-core";
export const ReceivableEvents = {
    reconnectionStatusChanged: "reconnectionStatusChanged",
};
const nativeModule = requireNativeModule("ReactNativeMobileWhepClient");
/** Creates a WHEP client based on the provided server URL and optional additional `configurationOptions`.
 *  It is a first step before connecting to the server.
 */
export function createWhepClient(
/** URL of the WHEP server from which the stream should be received. */
serverUrl, 
/** Additional configuration options. */
configurationOptions) {
    return nativeModule.createWhepClient(serverUrl, configurationOptions);
}
/** Connects to the WHEP server defined while creating WHEP client.
 * Allows user to receive video and audio stream.
 */
export async function connectWhepClient() {
    return await nativeModule.connectWhep();
}
/** Disconnects from the WHEP server defined while creating WHEP client.
 * Frees the resources.
 */
export function disconnectWhepClient() {
    return nativeModule.disconnectWhep();
}
/** Pauses the WHEP stream, making the view black and disabling the sound. */
export function pauseWhepClient() {
    return nativeModule.pauseWhep();
}
/** Restarts the WHEP stream. Makes the view reappear along with sound. */
export function unpauseWhepClient() {
    return nativeModule.unpauseWhep();
}
/** Creates a WHIP client based on the provided server URL and optional additional `configurationOptions`.
 * Allows user to choose a streaming device from all available cameras.
 *  It is a first step before connecting to the server.
 */
export function createWhipClient(serverUrl, configurationOptions, videoDevice) {
    return nativeModule.createWhipClient(serverUrl, configurationOptions, videoDevice);
}
/** Connects to the WHIP server defined while creating WHIP client.
 * Allows user to stream video and audio.
 */
export async function connectWhipClient() {
    return await nativeModule.connectWhip();
}
/** Disconnects from the WHIP server defined while creating WHIP client.
 * Frees the resources.
 */
export function disconnectWhipClient() {
    return nativeModule.disconnectWhip();
}
/** Gives access to the cameras available on the device.*/
export const cameras = nativeModule.cameras;
export default nativeModule;
//# sourceMappingURL=ReactNativeMobileWhepClientModule.js.map